==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/General/statusicon/translations/statusicon_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Status Icon Plugin Settings</source>
        <translation>状态图标插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Balloon message</source>
        <translation>气球通知</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Delay, ms:</source>
        <translation>延迟 [ms]：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Tooltip</source>
        <translation>工具提示</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="91"/>
        <source>Try to split file name when no tag</source>
        <translation>无标签时尝试拆分文件名</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="98"/>
        <source>Show progress bar</source>
        <translation>显示进度条</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Transparency:</source>
        <translation>透明度：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="165"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Cover size:</source>
        <translation>封面大小：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="214"/>
        <source>32</source>
        <translation>32</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="225"/>
        <source>Edit template</source>
        <translation>编辑模板</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="250"/>
        <source>Use standard icons</source>
        <translation>使用标准图标</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="80"/>
        <source>Tooltip Template</source>
        <translation>工具提示模板</translation>
    </message>
</context>
<context>
    <name>StatusIcon</name>
    <message>
        <location filename="../statusicon.cpp" line="66"/>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="67"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="68"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="70"/>
        <source>Next</source>
        <translation>下一曲</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="71"/>
        <source>Previous</source>
        <translation>上一曲</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="73"/>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="129"/>
        <source>Now Playing</source>
        <translation>正在播放</translation>
    </message>
</context>
<context>
    <name>StatusIconFactory</name>
    <message>
        <location filename="../statusiconfactory.cpp" line="30"/>
        <source>Status Icon Plugin</source>
        <translation>状态图标插件</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="50"/>
        <source>About Status Icon Plugin</source>
        <translation>关于状态图标插件</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="51"/>
        <source>Qmmp Status Icon Plugin</source>
        <translation>Qmmp 状态图标插件</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="52"/>
        <source>Written by:</source>
        <translation>作者：</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="53"/>
        <source>Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="54"/>
        <source>Artur Guzik &lt;a.guzik88@gmail.com&gt;</source>
        <translation>Artur Guzik &lt;a.guzik88@gmail.com&gt;</translation>
    </message>
</context>
<context>
    <name>StatusIconPopupWidget</name>
    <message>
        <location filename="../statusiconpopupwidget.cpp" line="135"/>
        <source>Stopped</source>
        <translation>已停止</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/General/statusicon/translations/statusicon_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Status Icon Plugin Settings</source>
        <translation>状态图标插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Balloon message</source>
        <translation>气球通知</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Delay, ms:</source>
        <translation>延迟 [ms]：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Tooltip</source>
        <translation>工具提示</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="91"/>
        <source>Try to split file name when no tag</source>
        <translation>无标签时尝试拆分文件名</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="98"/>
        <source>Show progress bar</source>
        <translation>显示进度条</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Transparency:</source>
        <translation>透明度：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="165"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Cover size:</source>
        <translation>封面大小：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="214"/>
        <source>32</source>
        <translation>32</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="225"/>
        <source>Edit template</source>
        <translation>编辑模板</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="250"/>
        <source>Use standard icons</source>
        <translation>使用标准图标</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="80"/>
        <source>Tooltip Template</source>
        <translation>工具提示模板</translation>
    </message>
</context>
<context>
    <name>StatusIcon</name>
    <message>
        <location filename="../statusicon.cpp" line="70"/>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="71"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="72"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="74"/>
        <source>Next</source>
        <translation>下一曲</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="75"/>
        <source>Previous</source>
        <translation>上一曲</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="77"/>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="119"/>
        <source>Stopped</source>
        <translation>被停止</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="144"/>
        <source>Now Playing</source>
        <translation>正在播放</translation>
    </message>
</context>
<context>
    <name>StatusIconFactory</name>
    <message>
        <location filename="../statusiconfactory.cpp" line="30"/>
        <source>Status Icon Plugin</source>
        <translation>状态图标插件</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="50"/>
        <source>About Status Icon Plugin</source>
        <translation>关于状态图标插件</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="51"/>
        <source>Qmmp Status Icon Plugin</source>
        <translation>Qmmp 状态图标插件</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="52"/>
        <source>Written by:</source>
        <translation>作者：</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="53"/>
        <source>Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="54"/>
        <source>Artur Guzik &lt;a.guzik88@gmail.com&gt;</source>
        <translation>Artur Guzik &lt;a.guzik88@gmail.com&gt;</translation>
    </message>
</context>
</TS>
